==> haskell-pretty-show-1.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.7
id: pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
key: pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
license: MIT
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
abi: 6113716a5efda4345adf3bac9f3dc9b0
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
import-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
depends:
    array-0.5.2.0 base-4.11.1.0
    haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3 pretty-1.1.3.6
    text-1.2.3.0 filepath-1.4.2 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3=1f3f67967dd9ff5e81fe50a81cdd4a36
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.8.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.8.1
id: pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
key: pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
license: MIT
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
abi: 80041e6bd348b4048d884d7cb6e8d993
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
import-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
depends:
    array-0.5.2.0 base-4.11.1.0
    haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3 pretty-1.1.3.6
    text-1.2.3.0 filepath-1.4.2 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3=1f3f67967dd9ff5e81fe50a81cdd4a36
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
